calendar

package
v0.0.0-...-39b9ff8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 22, 2021 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

const (
	Saturday int = iota
	Sunday
	Monday
	Tuesday
	Wednesday
	Thursday
	Friday
)

Variables

This section is empty.

Functions

func Congruence

func Congruence(month, day, year int) string

Congruence returns the day of week the month, day and year corresponds to. It is the callers responsibility to make sure month, day and year are valid.

Types

This section is empty.

Jump to