Documentation
¶
Index ¶
Constants ¶
const ( Saturday int = iota Sunday Monday Tuesday Wednesday Thursday Friday )
Variables ¶
This section is empty.
Functions ¶
func Congruence ¶
Congruence returns the day of week the month, day and year corresponds to. It is the callers responsibility to make sure month, day and year are valid.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.